@@ -148,7 +148,7 @@ func (s *clientSessions) openConnection(destAddr net.Addr, config *Config, tlsCo
 
 	quicConfig := &quic.Config{
 		ConnectionIDLength: 12,
-		MaxIdleTimeout:     time.Second * 30,
+		KeepAlive:          true,
 	}
 
 	conn, err := wrapSysConn(rawConn, config)
